@@ -13,6 +13,7 @@ sub try {
         || $class->_golang($d)
         || $class->_ruby($d)
         || $class->_vb($d)
+        || $class->_tool($d)
     ;
 }
 
@@ -383,6 +384,23 @@ sub _vb {
     }
 }
 
+sub _tool {
+    my ($class, $d) = @_;
+
+    if ( index($d->ua, 'PostmanRuntime') > -1 ) {
+        my $h = {
+            name => 'Postman',
+        };
+
+        if ($d->opt_version) {
+            my ($version) = ($d->ua =~ m!PostmanRuntime/([\d.]+)!);
+            $h->{version} = $version if $version;
+        }
+
+        return $h;
+    }
+}
+
 1;
 
 __END__
